moviepy.video.fx.all.accel_decel — MoviePy 1.0.1 documentation

# moviepy.video.fx.all.accel_decel

`moviepy.video.fx.all.` `accel_decel`(clip, new_duration=None, abruptness=1.0, soonness=1.0)
  new_duration

    If None, will be that of the current clip.

  abruptness

    negative abruptness (>-1): speed up down up zero abruptness : no effect positive abruptness: speed down up down

  soonness

    for positive abruptness, determines how soon the speedup occurs (0<soonness < inf)